<?php
if (!isset($gCms)) exit;
	$detailpage = '';

	if (!$this->CheckPermission('Modify GCharts'))
	{
		echo $this->ShowErrors($this->Lang('needpermission', array('Modify GCharts')));
		return;
	}

	if (isset($params['cancel']))
	{
		$this->Redirect($id, 'defaultadmin', $returnid);
	}

// Give the form id to smarty
$smarty->assign('formid',$id);

	$data = '';
	if (isset($params['data']))
	{
		$data = $params['data'];
	}

if( $this->CheckPermission('Approve GCharts') )
  {
    $status = 'published';
  }
	if (isset($params['status']))
	{
		$status = $params['status'];
	}

	$usedcategory = $this->GetPreference('default_category', '');
	if (isset($params['category']))
	{
		$usedcategory = $params['category'];
	}

	$userid = get_userid();

	$name = '';
	if (isset($params['name']))
	{
	  $name = $params['name'];
	}

	$element = '';
	if (isset($params['element']))
	{
	  $element = $params['element'];
	}

	$axisTitlesPosition = '';
	if (isset($params['axisTitlesPosition']))
	{
	  $axisTitlesPosition = $params['axisTitlesPosition'];
	}

	$backgroundColor = '';
	if (isset($params['backgroundColor']))
	{
	  $backgroundColor = $params['backgroundColor'];
	}

	$chartArea = '';
	if (isset($params['chartArea']))
	{
	  $chartArea = $params['chartArea'];
	}

	$colors = '';
	if (isset($params['colors']))
	{
	  $colors = $params['colors'];
	}

	$curveType = '';
	if (isset($params['curveType']))
	{
	  $curveType = $params['curveType'];
	}

	$enableInteractivity = '';
	if (isset($params['enableInteractivity']))
	{
	  $enableInteractivity = $params['enableInteractivity'];
	}

	$focusTarget = '';
	if (isset($params['focusTarget']))
	{
	  $focusTarget = $params['focusTarget'];
	}

	$fontSize = '';
	if (isset($params['fontSize']))
	{
	  $fontSize = $params['fontSize'];
	}

	$fontName = '';
	if (isset($params['fontName']))
	{
	  $fontName = $params['fontName'];
	}

	$hAxes = '';
	if (isset($params['hAxes']))
	{
	  $hAxes = $params['hAxes'];
	}

	$hAxis = '';
	if (isset($params['hAxis']))
	{
	  $hAxis = $params['hAxis'];
	}

	$height = '';
	if (isset($params['height']))
	{
	  $height = $params['height'];
	}

	$isHtml = '';
	if (isset($params['isHtml']))
	{
	  $isHtml = $params['isHtml'];
	}

	$isStacked = '';
	if (isset($params['isStacked']))
	{
	  $isStacked = $params['isStacked'];
	}

	$is3D = '';
	if (isset($params['is3D']))
	{
	  $is3D = $params['is3D'];
	}

	$interpolatedNulls = '';
	if (isset($params['interpolatedNulls']))
	{
	  $interpolatedNulls = $params['interpolatedNulls'];
	}

	$legend = '';
	if (isset($params['legend']))
	{
	  $legend = $params['legend'];
	}

	$lineWidth = '';
	if (isset($params['lineWidth']))
	{
	  $lineWidth = $params['lineWidth'];
	}

	$pointSize = '';
	if (isset($params['pointSize']))
	{
	  $pointSize = $params['pointSize'];
	}

	$pieResidueSliceColor = '';
	if (isset($params['pieResidueSliceColor']))
	{
	  $pieResidueSliceColor = $params['pieResidueSliceColor'];
	}

	$pieResidueSliceLabel = '';
	if (isset($params['pieResidueSliceLabel']))
	{
	  $pieResidueSliceLabel = $params['pieResidueSliceLabel'];
	}

	$pieSliceBorderColor = '';
	if (isset($params['pieSliceBorderColor']))
	{
	  $pieSliceBorderColor = $params['pieSliceBorderColor'];
	}

	$pieSliceText = '';
	if (isset($params['pieSliceText']))
	{
	  $pieSliceText = $params['pieSliceText'];
	}

	$pieSliceTextStyle = '';
	if (isset($params['pieSliceTextStyle']))
	{
	  $pieSliceTextStyle = $params['pieSliceTextStyle'];
	}

	$reverseCategories = '';
	if (isset($params['reverseCategories']))
	{
	  $reverseCategories = $params['reverseCategories'];
	}

	$slices = '';
	if (isset($params['slices']))
	{
	  $slices = $params['slices'];
	}

	$series = '';
	if (isset($params['series']))
	{
	  $series = $params['series'];
	}

	$sliceVisibilityThreshold = '';
	if (isset($params['sliceVisibilityThreshold']))
	{
	  $sliceVisibilityThreshold = $params['sliceVisibilityThreshold'];
	}

	$theme = '';
	if (isset($params['theme']))
	{
	  $theme = $params['theme'];
	}

	$title = '';
	if (isset($params['title']))
	{
	  $title = $params['title'];
	}

	$titlePosition = '';
	if (isset($params['titlePosition']))
	{
	  $titlePosition = $params['titlePosition'];
	}

	$titleTextStyle = '';
	if (isset($params['titleTextStyle']))
	{
	  $titleTextStyle = $params['titleTextStyle'];
	}

	$tooltip = '';
	if (isset($params['tooltip']))
	{
	  $tooltip = $params['tooltip'];
	}

	$vAxes = '';
	if (isset($params['vAxes']))
	{
	  $vAxes = $params['vAxes'];
	}

	$vAxis = '';
	if (isset($params['vAxis']))
	{
	  $vAxis = $params['vAxis'];
	}

	$width = '';
	if (isset($params['width']))
	{
	  $width = $params['width'];
	}

	$aggregationTarget = '';
	if (isset($params['aggregationTarget']))
	{
	  $aggregationTarget = $params['aggregationTarget'];
	}

	$groupWidth = '';
	if (isset($params['groupWidth']))
	{
	  $groupWidth = $params['groupWidth'];
	}

	$dataOpacity = '';
	if (isset($params['dataOpacity']))
	{
	  $dataOpacity = $params['dataOpacity'];
	}

	$avoidOverlappingGridLines = '';
	if (isset($params['avoidOverlappingGridLines']))
	{
	  $avoidOverlappingGridLines = $params['avoidOverlappingGridLines'];
	}

	$timeline = '';
	if (isset($params['timeline']))
	{
	  $timeline = $params['timeline'];
	}

	$allowHtml = '';
	if (isset($params['allowHtml']))
	{
	  $allowHtml = $params['allowHtml'];
	}

	$alternatingRowStyle = '';
	if (isset($params['alternatingRowStyle']))
	{
	  $alternatingRowStyle = $params['alternatingRowStyle'];
	}

	$cssClassNames = '';
	if (isset($params['cssClassNames']))
	{
	  $cssClassNames = $params['cssClassNames'];
	}

	$firstRowNumber = '';
	if (isset($params['firstRowNumber']))
	{
	  $firstRowNumber = $params['firstRowNumber'];
	}

	$chartpage = '';
	if (isset($params['chartpage']))
	{
	  $chartpage = $params['chartpage'];
	}

	$pageSize = '';
	if (isset($params['pageSize']))
	{
	  $pageSize = $params['pageSize'];
	}

	$rtlTable = '';
	if (isset($params['rtlTable']))
	{
	  $rtlTable = $params['rtlTable'];
	}

	$scrollLeftStartPosition = '';
	if (isset($params['scrollLeftStartPosition']))
	{
	  $scrollLeftStartPosition = $params['scrollLeftStartPosition'];
	}

	$showRowNumber = '';
	if (isset($params['showRowNumber']))
	{
	  $showRowNumber = $params['showRowNumber'];
	}

	$sort = '';
	if (isset($params['sort']))
	{
	  $sort = $params['sort'];
	}

	$sortAscending = '';
	if (isset($params['sortAscending']))
	{
	  $sortAscending = $params['sortAscending'];
	}

	$sortColumn = '';
	if (isset($params['sortColumn']))
	{
	  $sortColumn = $params['sortColumn'];
	}

	$startPage = '';
	if (isset($params['startPage']))
	{
	  $startPage = $params['startPage'];
	}

if( isset($params['submit']) )
  {
    $error = FALSE;
    if( empty($name) )
      {
	$error = $this->ShowErrors($this->Lang('nonamegiven'));
      }
    else if( empty($data) )
      {
	$error = $this->ShowErrors($this->Lang('nodatagiven'));
      }

    //
    // database work
    //
    if( $error !== FALSE )
      {
	echo $error;
      }
    else
      {
	$chartid = $db->GenID(cms_db_prefix()."module_gcharts_seq");
	$query = 'INSERT INTO '.cms_db_prefix().'module_gcharts (gcharts_id, gcharts_category_id, gcharts_element_id, gcharts_name, gcharts_data, axisTitlesPosition, backgroundColor, curveType, chartArea, colors, enableInteractivity, focusTarget, fontSize, fontName, hAxes, hAxis, height, interpolatedNulls, isHtml, isStacked, is3D, legend, lineWidth, slices, pieSliceBorderColor, pieSliceText, pieSliceTextStyle, pointSize, reverseCategories, series, sliceVisibilityThreshold, pieResidueSliceColor, pieResidueSliceLabel, theme, title, titlePosition, titleTextStyle, tooltip, vAxes, vAxis, width, status, aggregationTarget, groupWidth, dataOpacity, avoidOverlappingGridLines, timeline, allowHtml, alternatingRowStyle, cssClassNames, firstRowNumber, chartpage, pageSize, rtlTable, scrollLeftStartPosition, showRowNumber, sort, sortAscending, sortColumn, startPage) VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)';
	$dbr = $db->Execute($query, array($chartid, $usedcategory, $element, $name, $data, $axisTitlesPosition, $backgroundColor, $curveType, $chartArea, $colors, $enableInteractivity, $focusTarget, $fontSize, $fontName, $hAxes, $hAxis, $height, $interpolatedNulls, $isStacked, $isHtml, $is3D, $legend, $lineWidth, $slices, $pieSliceBorderColor, $pieSliceText, $pieSliceTextStyle, $pointSize, $reverseCategories, $series, $sliceVisibilityThreshold, $pieResidueSliceColor, $pieResidueSliceLabel, $theme, $title, $titlePosition, $titleTextStyle, $tooltip, $vAxes, $vAxis, $width, $status, $aggregationTarget, $groupWidth, $dataOpacity, $avoidOverlappingGridLines, $timeline, $allowHtml, $alternatingRowStyle, $cssClassNames, $firstRowNumber, $chartpage, $pageSize, $rtlTable, $scrollLeftStartPosition, $showRowNumber, $sort, $sortAscending, $sortColumn, $startPage));
    
	if( !$dbr )
	  {
	    echo "DEBUG: SQL = ".$db->sql."<br/>";
	    die($db->ErrorMsg());
	  }

	if( !$error && $status == 'published' )
	  {
	    //Update search index
	    $module = cms_utils::get_search_module();
	    if (is_object($module) )
	      {
		$text = '';
	    
		$text = $data.' '.$name;
		$module->AddWords($this->GetName(), $chartid, 'chart', $text);
	      }
	  }
	
	if( !$error )
	  {
	    @$this->SendEvent('ChartAdded', array('gcharts_id' => $chartid, 'category_id' => $usedcategory, 'gcharts_name' => $name, 'gcharts_data' => $data, 'status' => $status));
		// put mention into the admin log
		audit($chartid, 'GCharts: '.$chartid, 'Chart added');
	    $params = array('tab_message'=> 'chartadded', 'active_tab' => 'charts');
	    $this->Redirect($id, 'defaultadmin', $returnid, $params);
	  } // if !$error
      } // outer if !$error
  } // submit


//
// build the form
//    
$statusdropdown = array();
$statusdropdown[$this->Lang('draft')] = 'draft';
$statusdropdown[$this->Lang('published')] = 'published';
    
    $categorylist = array();
    $query = "SELECT * FROM ".cms_db_prefix()."module_gcharts_categories ORDER BY hierarchy";
    $dbresult = $db->Execute($query);
    
    while ($dbresult && $row = $dbresult->FetchRow())
      {
		$categorylist[$row['gcharts_category_name']] = $row['gcharts_category_id'];
	}

$onchangetext='onchange="document'.$id.'moduleform_1.submit()" id="chartCategory"';
	#Display template
	$smarty->assign('currcat', '1');
	$smarty->assign('hidden', '');
$smarty->assign('startform', $this->CreateFormStart($id, 'addchart', $returnid,'post','multipart/form-data'));
	$smarty->assign('endform', $this->CreateFormEnd());
	$smarty->assign('inputelement', $this->CreateInputText($id, 'element', $element, 30, 255));
	$smarty->assign('inputname', $this->CreateInputText($id, 'name', $name, 30, 255));
	$smarty->assign('inputdata', $this->CreateTextArea(false, $id, $data, 'data'));
	$smarty->assign('inputaxisTitlesPosition', $this->CreateInputText($id, 'axisTitlesPosition', $axisTitlesPosition, 30, 255));
	$smarty->assign('inputbackgroundColor', $this->CreateInputText($id, 'backgroundColor', $backgroundColor, 30, 255));
	$smarty->assign('inputchartArea', $this->CreateInputText($id, 'chartArea', $chartArea, 30, 255));
	$smarty->assign('inputcolors', $this->CreateInputText($id, 'colors', $colors, 30, 255));
	$smarty->assign('inputcurveType', $this->CreateInputText($id, 'curveType', $curveType, 30, 255));
	$smarty->assign('inputenableInteractivity', $this->CreateInputText($id, 'enableInteractivity', $enableInteractivity, 30, 255));
	$smarty->assign('inputfocusTarget', $this->CreateInputText($id, 'focusTarget', $focusTarget, 30, 255));
	$smarty->assign('inputfontSize', $this->CreateInputText($id, 'fontSize', $fontSize, 30, 255));
	$smarty->assign('inputfontName', $this->CreateInputText($id, 'fontName', $fontName, 30, 255));
	$smarty->assign('inputhAxes', $this->CreateInputText($id, 'hAxes', $hAxes, 30, 255));
	$smarty->assign('inputhAxis', $this->CreateInputText($id, 'hAxis', $hAxis, 30, 255));
	$smarty->assign('inputheight', $this->CreateInputText($id, 'height', $height, 30, 255));
	$smarty->assign('inputinterpolatedNulls', $this->CreateInputText($id, 'interpolatedNulls', $interpolatedNulls, 30, 255));
	$smarty->assign('inputisHtml', $this->CreateInputText($id, 'isHtml', $isHtml, 30, 255));
	$smarty->assign('inputisStacked', $this->CreateInputText($id, 'isStacked', $isStacked, 30, 255));
	$smarty->assign('inputis3D', $this->CreateInputText($id, 'is3D', $is3D, 30, 255));
	$smarty->assign('inputlegend', $this->CreateInputText($id, 'legend', $legend, 30, 255));
	$smarty->assign('inputlineWidth', $this->CreateInputText($id, 'lineWidth', $lineWidth, 30, 255));
	$smarty->assign('inputslices', $this->CreateInputText($id, 'slices', $slices, 30, 255));
	$smarty->assign('inputpieSliceBorderColor', $this->CreateInputText($id, 'pieSliceBorderColor', $pieSliceBorderColor, 30, 255));
	$smarty->assign('inputpieSliceText', $this->CreateInputText($id, 'pieSliceText', $pieSliceText, 30, 255));
	$smarty->assign('inputpieSliceTextStyle', $this->CreateInputText($id, 'pieSliceTextStyle', $pieSliceTextStyle, 30, 255));
	$smarty->assign('inputpointSize', $this->CreateInputText($id, 'pointSize', $pointSize, 30, 255));
	$smarty->assign('inputreverseCategories', $this->CreateInputText($id, 'reverseCategories', $reverseCategories, 30, 255));
	$smarty->assign('inputseries', $this->CreateInputText($id, 'series', $series, 30, 255));
	$smarty->assign('inputsliceVisibilityThreshold', $this->CreateInputText($id, 'sliceVisibilityThreshold', $sliceVisibilityThreshold, 30, 255));
	$smarty->assign('inputpieResidueSliceColor', $this->CreateInputText($id, 'pieResidueSliceColor', $pieResidueSliceColor, 30, 255));
	$smarty->assign('inputpieResidueSliceLabel', $this->CreateInputText($id, 'pieResidueSliceLabel', $pieResidueSliceLabel, 30, 255));
	$smarty->assign('inputtheme', $this->CreateInputText($id, 'theme', $theme, 30, 255));
	$smarty->assign('inputtitle', $this->CreateInputText($id, 'title', $title, 30, 255));
	$smarty->assign('inputtitlePosition', $this->CreateInputText($id, 'titlePosition', $titlePosition, 30, 255));
	$smarty->assign('inputtitleTextStyle', $this->CreateInputText($id, 'titleTextStyle', $titleTextStyle, 30, 255));
	$smarty->assign('inputtooltip', $this->CreateInputText($id, 'tooltip', $tooltip, 30, 255));
	$smarty->assign('inputvAxes', $this->CreateInputText($id, 'tooltip', $vAxes, 30, 255));
	$smarty->assign('inputvAxis', $this->CreateInputText($id, 'vAxis', $vAxis, 30, 255));
	$smarty->assign('inputwidth', $this->CreateInputText($id, 'width', $width, 30, 255));
	$smarty->assign('inputaggregationTarget', $this->CreateInputText($id, 'aggregationTarget', $aggregationTarget, 30, 255));
	$smarty->assign('inputgroupWidth', $this->CreateInputText($id, 'groupWidth', $groupWidth, 30, 255));
	$smarty->assign('inputdataOpacity', $this->CreateInputText($id, 'dataOpacity', $dataOpacity, 30, 255));
	$smarty->assign('inputavoidOverlappingGridLines', $this->CreateInputText($id, 'avoidOverlappingGridLines', $avoidOverlappingGridLines, 30, 255));
	$smarty->assign('inputtimeline', $this->CreateInputText($id, 'timeline', $timeline, 30, 255));
	$smarty->assign('inputallowHtml', $this->CreateInputText($id, 'allowHtml', $allowHtml, 30, 255));
	$smarty->assign('inputalternatingRowStyle', $this->CreateInputText($id, 'alternatingRowStyle', $alternatingRowStyle, 30, 255));
	$smarty->assign('inputcssClassNames', $this->CreateInputText($id, 'cssClassNames', $cssClassNames, 30, 255));
	$smarty->assign('inputfirstRowNumber', $this->CreateInputText($id, 'firstRowNumber', $firstRowNumber, 30, 255));
	$smarty->assign('inputchartpage', $this->CreateInputText($id, 'chartpage', $chartpage, 30, 255));
	$smarty->assign('inputpageSize', $this->CreateInputText($id, 'pageSize', $pageSize, 30, 255));
	$smarty->assign('inputrtlTable', $this->CreateInputText($id, 'rtlTable', $rtlTable, 30, 255));
	$smarty->assign('inputscrollLeftStartPosition', $this->CreateInputText($id, 'scrollLeftStartPosition', $scrollLeftStartPosition, 30, 255));
	$smarty->assign('inputshowRowNumber', $this->CreateInputText($id, 'showRowNumber', $showRowNumber, 30, 255));
	$smarty->assign('inputsort', $this->CreateInputText($id, 'sort', $sort, 30, 255));
	$smarty->assign('inputsortAscending', $this->CreateInputText($id, 'sortAscending', $sortAscending, 30, 255));
	$smarty->assign('inputsortColumn', $this->CreateInputText($id, 'sortColumn', $sortColumn, 30, 255));
	$smarty->assign('inputstartPage', $this->CreateInputText($id, 'startPage', $startPage, 30, 255));
$smarty->assign('actionid',$id);
if( $this->CheckPermission('Approve GCharts') )
  {
    $smarty->assign('statustext', lang('status'));
    $smarty->assign('status', $this->CreateInputDropdown($id, 'status', $statusdropdown, -1, $status));
  }
 else
   {
    $smarty->assign('status',$this->CreateInputHidden($id,'status',$status));
   }
$smarty->assign('inputcategory', $this->CreateInputDropdown($id, 'category', $categorylist, -1, $usedcategory, $onchangetext));
	$smarty->assign('submit', $this->CreateInputSubmit($id, 'submit', lang('submit')));
	$smarty->assign('cancel', $this->CreateInputSubmit($id, 'cancel', lang('cancel')));

	$smarty->assign('nametext', $this->Lang('name'));
	$smarty->assign('elementtext', $this->Lang('element'));
	$smarty->assign('categorytext', $this->Lang('category'));
	$smarty->assign('datatext', $this->Lang('data'));
	$smarty->assign('axisTitlesPositiontext', $this->Lang('axisTitlesPosition'));
	$smarty->assign('backgroundColortext', $this->Lang('backgroundColor'));
	$smarty->assign('chartAreatext', $this->Lang('chartArea'));
	$smarty->assign('colorstext', $this->Lang('colors'));
	$smarty->assign('curveTypetext', $this->Lang('curveType'));
	$smarty->assign('enableInteractivitytext', $this->Lang('enableInteractivity'));
	$smarty->assign('focusTargettext', $this->Lang('focusTarget'));
	$smarty->assign('fontSizetext', $this->Lang('fontSize'));
	$smarty->assign('fontNametext', $this->Lang('fontName'));
	$smarty->assign('hAxestext', $this->Lang('hAxes'));
	$smarty->assign('hAxistext', $this->Lang('hAxis'));
	$smarty->assign('heighttext', $this->Lang('height'));
	$smarty->assign('interpolatedNullstext', $this->Lang('interpolatedNulls'));
	$smarty->assign('isHtmltext', $this->Lang('isHtml'));
	$smarty->assign('isStackedtext', $this->Lang('isStacked'));
	$smarty->assign('is3Dtext', $this->Lang('is3D'));
	$smarty->assign('legendtext', $this->Lang('legend'));
	$smarty->assign('lineWidthtext', $this->Lang('lineWidth'));
	$smarty->assign('slicestext', $this->Lang('slices'));
	$smarty->assign('pieSliceBorderColortext', $this->Lang('pieSliceBorderColor'));
	$smarty->assign('pieSliceTexttext', $this->Lang('pieSliceText'));
	$smarty->assign('pieSliceTextStyletext', $this->Lang('pieSliceTextStyle'));
	$smarty->assign('pointSizetext', $this->Lang('pointSize'));
	$smarty->assign('reverseCategoriestext', $this->Lang('reverseCategories'));
	$smarty->assign('seriestext', $this->Lang('series'));
	$smarty->assign('sliceVisibilityThresholdtext', $this->Lang('sliceVisibilityThreshold'));
	$smarty->assign('pieResidueSliceColortext', $this->Lang('pieResidueSliceColor'));
	$smarty->assign('pieResidueSliceLabeltext', $this->Lang('pieResidueSliceLabel'));
	$smarty->assign('themetext', $this->Lang('theme'));
	$smarty->assign('titletext', $this->Lang('title'));
	$smarty->assign('titlePositiontext', $this->Lang('titlePosition'));
	$smarty->assign('titleTextStyletext', $this->Lang('titleTextStyle'));
	$smarty->assign('tooltiptext', $this->Lang('tooltip'));
	$smarty->assign('vAxestext', $this->Lang('vAxes'));
	$smarty->assign('vAxistext', $this->Lang('vAxis'));
	$smarty->assign('widthtext', $this->Lang('width'));
	$smarty->assign('aggregationTargettext', $this->Lang('aggregationTarget'));
	$smarty->assign('groupWidthtext', $this->Lang('groupWidth'));
	$smarty->assign('dataOpacitytext', $this->Lang('dataOpacity'));
	$smarty->assign('avoidOverlappingGridLinestext', $this->Lang('avoidOverlappingGridLines'));
	$smarty->assign('timelinetext', $this->Lang('timeline'));
	$smarty->assign('allowHtmltext', $this->Lang('allowHtml'));
	$smarty->assign('alternatingRowStyletext', $this->Lang('alternatingRowStyle'));
	$smarty->assign('cssClassNamestext', $this->Lang('cssClassNames'));
	$smarty->assign('firstRowNumbertext', $this->Lang('firstRowNumber'));
	$smarty->assign('chartpagetext', $this->Lang('chartpage'));
	$smarty->assign('pageSizetext', $this->Lang('pageSize'));
	$smarty->assign('rtlTabletext', $this->Lang('rtlTable'));
	$smarty->assign('scrollLeftStartPositiontext', $this->Lang('scrollLeftStartPosition'));
	$smarty->assign('showRowNumbertext', $this->Lang('showRowNumber'));
	$smarty->assign('sorttext', $this->Lang('sort'));
	$smarty->assign('sortAscendingtext', $this->Lang('sortAscending'));
	$smarty->assign('sortColumntext', $this->Lang('sortColumn'));
	$smarty->assign('startPagetext', $this->Lang('startPage'));

// tab stuff.
$smarty->assign('start_tab_headers',$this->StartTabHeaders());
$smarty->assign('tabheader_chart',$this->SetTabHeader('chart',$this->Lang('chart')));
$smarty->assign('end_tab_headers',$this->EndTabHeaders());

$smarty->assign('start_tab_content',$this->StartTabContent());
$smarty->assign('start_tab_chart',$this->StartTab('chart',$params));
$smarty->assign('end_tab_chart',$this->EndTab());
$smarty->assign('end_tab_content',$this->EndTabContent());

$smarty->assign('warning_preview',$this->Lang('warning_preview'));
$contentops = cmsms()->GetContentOperations();
$smarty->assign('preview_returnid',
		$contentops->CreateHierarchyDropdown('',$this->GetPreference('detail_returnid',-1),
						     'preview_returnid'));
{
  $tmp = $this->ListTemplates();
  $tmp2 = array();
  for( $i = 0; $i < count($tmp); $i++ )
    {
      if( startswith($tmp[$i],'detail') )
	{
	  $x = substr($tmp[$i],6);
	  $tmp2[$x] = $x;
	}
    }
  $smarty->assign('prompt_detail_template',$this->Lang('detail_template'));
  $smarty->assign('prompt_detail_page',$this->Lang('detail_page'));
  $smarty->assign('detail_templates',$tmp2);
  $smarty->assign('cur_detail_template',$this->GetPreference('current_detail_template'));
}
echo $this->ProcessTemplate('editchart.tpl');
?>
